# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from testpb import test_schema_query_pb2 as testpb_dot_test__schema__query__pb2


class TestSchemaQueryServiceStub(object):
    """TestSchemaQueryService queries the state of the tables specified by testpb/test_schema.proto.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetExampleTable = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleTable',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleTableRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTableResponse.FromString,
                )
        self.GetExampleTableByU64Str = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleTableByU64Str',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrResponse.FromString,
                )
        self.ListExampleTable = channel.unary_unary(
                '/testpb.TestSchemaQueryService/ListExampleTable',
                request_serializer=testpb_dot_test__schema__query__pb2.ListExampleTableRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.ListExampleTableResponse.FromString,
                )
        self.GetExampleAutoIncrementTable = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleAutoIncrementTable',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableResponse.FromString,
                )
        self.GetExampleAutoIncrementTableByX = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleAutoIncrementTableByX',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXResponse.FromString,
                )
        self.ListExampleAutoIncrementTable = channel.unary_unary(
                '/testpb.TestSchemaQueryService/ListExampleAutoIncrementTable',
                request_serializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableResponse.FromString,
                )
        self.GetExampleSingleton = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleSingleton',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleSingletonRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleSingletonResponse.FromString,
                )
        self.GetExampleTimestamp = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleTimestamp',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleTimestampRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTimestampResponse.FromString,
                )
        self.ListExampleTimestamp = channel.unary_unary(
                '/testpb.TestSchemaQueryService/ListExampleTimestamp',
                request_serializer=testpb_dot_test__schema__query__pb2.ListExampleTimestampRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.ListExampleTimestampResponse.FromString,
                )
        self.GetSimpleExample = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetSimpleExample',
                request_serializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleResponse.FromString,
                )
        self.GetSimpleExampleByUnique = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetSimpleExampleByUnique',
                request_serializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueResponse.FromString,
                )
        self.ListSimpleExample = channel.unary_unary(
                '/testpb.TestSchemaQueryService/ListSimpleExample',
                request_serializer=testpb_dot_test__schema__query__pb2.ListSimpleExampleRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.ListSimpleExampleResponse.FromString,
                )
        self.GetExampleAutoIncFieldName = channel.unary_unary(
                '/testpb.TestSchemaQueryService/GetExampleAutoIncFieldName',
                request_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameResponse.FromString,
                )
        self.ListExampleAutoIncFieldName = channel.unary_unary(
                '/testpb.TestSchemaQueryService/ListExampleAutoIncFieldName',
                request_serializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameRequest.SerializeToString,
                response_deserializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameResponse.FromString,
                )


class TestSchemaQueryServiceServicer(object):
    """TestSchemaQueryService queries the state of the tables specified by testpb/test_schema.proto.
    """

    def GetExampleTable(self, request, context):
        """Get queries the ExampleTable table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleTableByU64Str(self, request, context):
        """GetExampleTableByU64Str queries the ExampleTable table by its U64Str index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExampleTable(self, request, context):
        """ListExampleTable queries the ExampleTable table using prefix and range queries against defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleAutoIncrementTable(self, request, context):
        """Get queries the ExampleAutoIncrementTable table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleAutoIncrementTableByX(self, request, context):
        """GetExampleAutoIncrementTableByX queries the ExampleAutoIncrementTable table by its X index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExampleAutoIncrementTable(self, request, context):
        """ListExampleAutoIncrementTable queries the ExampleAutoIncrementTable table using prefix and range queries against
        defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleSingleton(self, request, context):
        """GetExampleSingleton queries the ExampleSingleton singleton.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleTimestamp(self, request, context):
        """Get queries the ExampleTimestamp table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExampleTimestamp(self, request, context):
        """ListExampleTimestamp queries the ExampleTimestamp table using prefix and range queries against defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSimpleExample(self, request, context):
        """Get queries the SimpleExample table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSimpleExampleByUnique(self, request, context):
        """GetSimpleExampleByUnique queries the SimpleExample table by its Unique index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSimpleExample(self, request, context):
        """ListSimpleExample queries the SimpleExample table using prefix and range queries against defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExampleAutoIncFieldName(self, request, context):
        """Get queries the ExampleAutoIncFieldName table by its primary key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExampleAutoIncFieldName(self, request, context):
        """ListExampleAutoIncFieldName queries the ExampleAutoIncFieldName table using prefix and range queries against
        defined indexes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TestSchemaQueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetExampleTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleTable,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTableRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleTableResponse.SerializeToString,
            ),
            'GetExampleTableByU64Str': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleTableByU64Str,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrResponse.SerializeToString,
            ),
            'ListExampleTable': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExampleTable,
                    request_deserializer=testpb_dot_test__schema__query__pb2.ListExampleTableRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.ListExampleTableResponse.SerializeToString,
            ),
            'GetExampleAutoIncrementTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleAutoIncrementTable,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableResponse.SerializeToString,
            ),
            'GetExampleAutoIncrementTableByX': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleAutoIncrementTableByX,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXResponse.SerializeToString,
            ),
            'ListExampleAutoIncrementTable': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExampleAutoIncrementTable,
                    request_deserializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableResponse.SerializeToString,
            ),
            'GetExampleSingleton': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleSingleton,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleSingletonRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleSingletonResponse.SerializeToString,
            ),
            'GetExampleTimestamp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleTimestamp,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleTimestampRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleTimestampResponse.SerializeToString,
            ),
            'ListExampleTimestamp': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExampleTimestamp,
                    request_deserializer=testpb_dot_test__schema__query__pb2.ListExampleTimestampRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.ListExampleTimestampResponse.SerializeToString,
            ),
            'GetSimpleExample': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSimpleExample,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleResponse.SerializeToString,
            ),
            'GetSimpleExampleByUnique': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSimpleExampleByUnique,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueResponse.SerializeToString,
            ),
            'ListSimpleExample': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSimpleExample,
                    request_deserializer=testpb_dot_test__schema__query__pb2.ListSimpleExampleRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.ListSimpleExampleResponse.SerializeToString,
            ),
            'GetExampleAutoIncFieldName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExampleAutoIncFieldName,
                    request_deserializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameResponse.SerializeToString,
            ),
            'ListExampleAutoIncFieldName': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExampleAutoIncFieldName,
                    request_deserializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameRequest.FromString,
                    response_serializer=testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'testpb.TestSchemaQueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TestSchemaQueryService(object):
    """TestSchemaQueryService queries the state of the tables specified by testpb/test_schema.proto.
    """

    @staticmethod
    def GetExampleTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleTable',
            testpb_dot_test__schema__query__pb2.GetExampleTableRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleTableByU64Str(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleTableByU64Str',
            testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleTableByU64StrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExampleTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/ListExampleTable',
            testpb_dot_test__schema__query__pb2.ListExampleTableRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.ListExampleTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleAutoIncrementTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleAutoIncrementTable',
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleAutoIncrementTableByX(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleAutoIncrementTableByX',
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncrementTableByXResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExampleAutoIncrementTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/ListExampleAutoIncrementTable',
            testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.ListExampleAutoIncrementTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleSingleton(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleSingleton',
            testpb_dot_test__schema__query__pb2.GetExampleSingletonRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleSingletonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleTimestamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleTimestamp',
            testpb_dot_test__schema__query__pb2.GetExampleTimestampRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleTimestampResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExampleTimestamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/ListExampleTimestamp',
            testpb_dot_test__schema__query__pb2.ListExampleTimestampRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.ListExampleTimestampResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSimpleExample(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetSimpleExample',
            testpb_dot_test__schema__query__pb2.GetSimpleExampleRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetSimpleExampleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSimpleExampleByUnique(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetSimpleExampleByUnique',
            testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetSimpleExampleByUniqueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSimpleExample(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/ListSimpleExample',
            testpb_dot_test__schema__query__pb2.ListSimpleExampleRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.ListSimpleExampleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExampleAutoIncFieldName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/GetExampleAutoIncFieldName',
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.GetExampleAutoIncFieldNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExampleAutoIncFieldName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/testpb.TestSchemaQueryService/ListExampleAutoIncFieldName',
            testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameRequest.SerializeToString,
            testpb_dot_test__schema__query__pb2.ListExampleAutoIncFieldNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/autocli/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.autocli.v1 import options_pb2 as cosmos_dot_autocli_dot_v1_dot_options__pb2
from cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/autocli/v1/query.proto\x12\x11\x63osmos.autocli.v1\x1a\x1f\x63osmos/autocli/v1/options.proto\x1a\x1b\x63osmos/query/v1/query.proto\"\x13\n\x11\x41ppOptionsRequest\"\xbe\x01\n\x12\x41ppOptionsResponse\x12P\n\x0emodule_options\x18\x01 \x03(\x0b\x32\x38.cosmos.autocli.v1.AppOptionsResponse.ModuleOptionsEntry\x1aV\n\x12ModuleOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .cosmos.autocli.v1.ModuleOptions:\x02\x38\x01\x32i\n\x05Query\x12`\n\nAppOptions\x12$.cosmos.autocli.v1.AppOptionsRequest\x1a%.cosmos.autocli.v1.AppOptionsResponse\"\x05\x88\xe7\xb0*\x00\x42+Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.autocli.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)cosmossdk.io/api/cosmos/base/cli/v1;cliv1'
  _APPOPTIONSRESPONSE_MODULEOPTIONSENTRY._options = None
  _APPOPTIONSRESPONSE_MODULEOPTIONSENTRY._serialized_options = b'8\001'
  _QUERY.methods_by_name['AppOptions']._options = None
  _QUERY.methods_by_name['AppOptions']._serialized_options = b'\210\347\260*\000'
  _globals['_APPOPTIONSREQUEST']._serialized_start=114
  _globals['_APPOPTIONSREQUEST']._serialized_end=133
  _globals['_APPOPTIONSRESPONSE']._serialized_start=136
  _globals['_APPOPTIONSRESPONSE']._serialized_end=326
  _globals['_APPOPTIONSRESPONSE_MODULEOPTIONSENTRY']._serialized_start=240
  _globals['_APPOPTIONSRESPONSE_MODULEOPTIONSENTRY']._serialized_end=326
  _globals['_QUERY']._serialized_start=328
  _globals['_QUERY']._serialized_end=433
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/v1/orm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63osmos/orm/v1/orm.proto\x12\rcosmos.orm.v1\x1a google/protobuf/descriptor.proto\"\x8f\x01\n\x0fTableDescriptor\x12\x38\n\x0bprimary_key\x18\x01 \x01(\x0b\x32#.cosmos.orm.v1.PrimaryKeyDescriptor\x12\x36\n\x05index\x18\x02 \x03(\x0b\x32\'.cosmos.orm.v1.SecondaryIndexDescriptor\x12\n\n\x02id\x18\x03 \x01(\r\">\n\x14PrimaryKeyDescriptor\x12\x0e\n\x06\x66ields\x18\x01 \x01(\t\x12\x16\n\x0e\x61uto_increment\x18\x02 \x01(\x08\"F\n\x18SecondaryIndexDescriptor\x12\x0e\n\x06\x66ields\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0e\n\x06unique\x18\x03 \x01(\x08\"!\n\x13SingletonDescriptor\x12\n\n\x02id\x18\x01 \x01(\r:Q\n\x05table\x12\x1f.google.protobuf.MessageOptions\x18\xee\xb3\xea\x31 \x01(\x0b\x32\x1e.cosmos.orm.v1.TableDescriptor:Y\n\tsingleton\x12\x1f.google.protobuf.MessageOptions\x18\xef\xb3\xea\x31 \x01(\x0b\x32\".cosmos.orm.v1.SingletonDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.v1.orm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(table)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(singleton)

  DESCRIPTOR._options = None
  _globals['_TABLEDESCRIPTOR']._serialized_start=77
  _globals['_TABLEDESCRIPTOR']._serialized_end=220
  _globals['_PRIMARYKEYDESCRIPTOR']._serialized_start=222
  _globals['_PRIMARYKEYDESCRIPTOR']._serialized_end=284
  _globals['_SECONDARYINDEXDESCRIPTOR']._serialized_start=286
  _globals['_SECONDARYINDEXDESCRIPTOR']._serialized_end=356
  _globals['_SINGLETONDESCRIPTOR']._serialized_start=358
  _globals['_SINGLETONDESCRIPTOR']._serialized_end=391
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/oracle/v1beta1/proposal.proto\x12\x18injective.oracle.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x80\x01\n GrantBandOraclePrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08relayers\x18\x03 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x81\x01\n!RevokeBandOraclePrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08relayers\x18\x03 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x9e\x01\n!GrantPriceFeederPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\r\n\x05quote\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x90\x01\n\x1eGrantProviderPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x10\n\x08relayers\x18\x04 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x91\x01\n\x1fRevokeProviderPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x9f\x01\n\"RevokePriceFeederPrivilegeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\r\n\x05quote\x18\x04 \x01(\t\x12\x10\n\x08relayers\x18\x05 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xb4\x01\n\"AuthorizeBandOracleRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x07request\x18\x03 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequestB\x04\xc8\xde\x1f\x00:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xd5\x01\n\x1fUpdateBandOracleRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65lete_request_ids\x18\x03 \x03(\x04\x12J\n\x15update_oracle_request\x18\x04 \x01(\x0b\x32+.injective.oracle.v1beta1.BandOracleRequest:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xab\x01\n\x15\x45nableBandIBCProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x46\n\x0f\x62\x61nd_ibc_params\x18\x03 \x01(\x0b\x32\'.injective.oracle.v1beta1.BandIBCParamsB\x04\xc8\xde\x1f\x00:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.ContentBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _GRANTBANDORACLEPRIVILEGEPROPOSAL._options = None
  _GRANTBANDORACLEPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _REVOKEBANDORACLEPRIVILEGEPROPOSAL._options = None
  _REVOKEBANDORACLEPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _GRANTPRICEFEEDERPRIVILEGEPROPOSAL._options = None
  _GRANTPRICEFEEDERPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _GRANTPROVIDERPRIVILEGEPROPOSAL._options = None
  _GRANTPROVIDERPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _REVOKEPROVIDERPRIVILEGEPROPOSAL._options = None
  _REVOKEPROVIDERPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _REVOKEPRICEFEEDERPRIVILEGEPROPOSAL._options = None
  _REVOKEPRICEFEEDERPRIVILEGEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _AUTHORIZEBANDORACLEREQUESTPROPOSAL.fields_by_name['request']._options = None
  _AUTHORIZEBANDORACLEREQUESTPROPOSAL.fields_by_name['request']._serialized_options = b'\310\336\037\000'
  _AUTHORIZEBANDORACLEREQUESTPROPOSAL._options = None
  _AUTHORIZEBANDORACLEREQUESTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _UPDATEBANDORACLEREQUESTPROPOSAL._options = None
  _UPDATEBANDORACLEREQUESTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _ENABLEBANDIBCPROPOSAL.fields_by_name['band_ibc_params']._options = None
  _ENABLEBANDIBCPROPOSAL.fields_by_name['band_ibc_params']._serialized_options = b'\310\336\037\000'
  _ENABLEBANDIBCPROPOSAL._options = None
  _ENABLEBANDIBCPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._serialized_start=190
  _globals['_GRANTBANDORACLEPRIVILEGEPROPOSAL']._serialized_end=318
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._serialized_start=321
  _globals['_REVOKEBANDORACLEPRIVILEGEPROPOSAL']._serialized_end=450
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_start=453
  _globals['_GRANTPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_end=611
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._serialized_start=614
  _globals['_GRANTPROVIDERPRIVILEGEPROPOSAL']._serialized_end=758
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._serialized_start=761
  _globals['_REVOKEPROVIDERPRIVILEGEPROPOSAL']._serialized_end=906
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_start=909
  _globals['_REVOKEPRICEFEEDERPRIVILEGEPROPOSAL']._serialized_end=1068
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._serialized_start=1071
  _globals['_AUTHORIZEBANDORACLEREQUESTPROPOSAL']._serialized_end=1251
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._serialized_start=1254
  _globals['_UPDATEBANDORACLEREQUESTPROPOSAL']._serialized_end=1467
  _globals['_ENABLEBANDIBCPROPOSAL']._serialized_start=1470
  _globals['_ENABLEBANDIBCPROPOSAL']._serialized_end=1641
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from injective.peggy.v1 import params_pb2 as injective_dot_peggy_dot_v1_dot_params__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dinjective/peggy/v1/msgs.proto\x12\x12injective.peggy.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1finjective/peggy/v1/params.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\"X\n\x1bMsgSetOrchestratorAddresses\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\"%\n#MsgSetOrchestratorAddressesResponse\"r\n\x10MsgValsetConfirm\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x14\n\x0corchestrator\x18\x02 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x1a\n\x18MsgValsetConfirmResponse\"\xa3\x01\n\x0cMsgSendToEth\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x65th_dest\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x33\n\nbridge_fee\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x16\n\x14MsgSendToEthResponse\"I\n\x0fMsgRequestBatch\x12\x14\n\x0corchestrator\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x19\n\x17MsgRequestBatchResponse\"\x88\x01\n\x0fMsgConfirmBatch\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x02 \x01(\t\x12\x12\n\neth_signer\x18\x03 \x01(\t\x12\x14\n\x0corchestrator\x18\x04 \x01(\t\x12\x11\n\tsignature\x18\x05 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x19\n\x17MsgConfirmBatchResponse\"\xfd\x01\n\x0fMsgDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x03 \x01(\t\x12>\n\x06\x61mount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x17\n\x0f\x65thereum_sender\x18\x05 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x06 \x01(\t\x12\x14\n\x0corchestrator\x18\x07 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x19\n\x17MsgDepositClaimResponse\"\x93\x01\n\x10MsgWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x14\n\x0corchestrator\x18\x05 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x1a\n\x18MsgWithdrawClaimResponse\"\xc9\x01\n\x15MsgERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\x12\x14\n\x0c\x63osmos_denom\x18\x03 \x01(\t\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x07 \x01(\x04\x12\x14\n\x0corchestrator\x18\x08 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x1f\n\x1dMsgERC20DeployedClaimResponse\"I\n\x12MsgCancelSendToEth\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t:\x0b\x82\xe7\xb0*\x06sender\"\x1c\n\x1aMsgCancelSendToEthResponse\"v\n\x1dMsgSubmitBadSignatureEvidence\x12%\n\x07subject\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tsignature\x18\x02 \x01(\t\x12\x0e\n\x06sender\x18\x03 \x01(\t:\x0b\x82\xe7\xb0*\x06sender\"\'\n%MsgSubmitBadSignatureEvidenceResponse\"\x94\x02\n\x15MsgValsetUpdatedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0cvalset_nonce\x18\x02 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x03 \x01(\x04\x12\x34\n\x07members\x18\x04 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x14\n\x0creward_token\x18\x06 \x01(\t\x12\x14\n\x0corchestrator\x18\x07 \x01(\t:\x11\x82\xe7\xb0*\x0corchestrator\"\x1f\n\x1dMsgValsetUpdatedClaimResponse\"\x80\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xa6\x0e\n\x03Msg\x12\x8f\x01\n\rValsetConfirm\x12$.injective.peggy.v1.MsgValsetConfirm\x1a,.injective.peggy.v1.MsgValsetConfirmResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/valset_confirm\x12\x80\x01\n\tSendToEth\x12 .injective.peggy.v1.MsgSendToEth\x1a(.injective.peggy.v1.MsgSendToEthResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/injective/peggy/v1/send_to_eth\x12\x8b\x01\n\x0cRequestBatch\x12#.injective.peggy.v1.MsgRequestBatch\x1a+.injective.peggy.v1.MsgRequestBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/request_batch\x12\x8b\x01\n\x0c\x43onfirmBatch\x12#.injective.peggy.v1.MsgConfirmBatch\x1a+.injective.peggy.v1.MsgConfirmBatchResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/confirm_batch\x12\x8b\x01\n\x0c\x44\x65positClaim\x12#.injective.peggy.v1.MsgDepositClaim\x1a+.injective.peggy.v1.MsgDepositClaimResponse\")\x82\xd3\xe4\x93\x02#\"!/injective/peggy/v1/deposit_claim\x12\x8f\x01\n\rWithdrawClaim\x12$.injective.peggy.v1.MsgWithdrawClaim\x1a,.injective.peggy.v1.MsgWithdrawClaimResponse\"*\x82\xd3\xe4\x93\x02$\"\"/injective/peggy/v1/withdraw_claim\x12\xa3\x01\n\x11ValsetUpdateClaim\x12).injective.peggy.v1.MsgValsetUpdatedClaim\x1a\x31.injective.peggy.v1.MsgValsetUpdatedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/valset_updated_claim\x12\xa4\x01\n\x12\x45RC20DeployedClaim\x12).injective.peggy.v1.MsgERC20DeployedClaim\x1a\x31.injective.peggy.v1.MsgERC20DeployedClaimResponse\"0\x82\xd3\xe4\x93\x02*\"(/injective/peggy/v1/erc20_deployed_claim\x12\xba\x01\n\x18SetOrchestratorAddresses\x12/.injective.peggy.v1.MsgSetOrchestratorAddresses\x1a\x37.injective.peggy.v1.MsgSetOrchestratorAddressesResponse\"4\x82\xd3\xe4\x93\x02.\",/injective/peggy/v1/set_orchestrator_address\x12\x99\x01\n\x0f\x43\x61ncelSendToEth\x12&.injective.peggy.v1.MsgCancelSendToEth\x1a..injective.peggy.v1.MsgCancelSendToEthResponse\".\x82\xd3\xe4\x93\x02(\"&/injective/peggy/v1/cancel_send_to_eth\x12\xc5\x01\n\x1aSubmitBadSignatureEvidence\x12\x31.injective.peggy.v1.MsgSubmitBadSignatureEvidence\x1a\x39.injective.peggy.v1.MsgSubmitBadSignatureEvidenceResponse\"9\x82\xd3\xe4\x93\x02\x33\"1/injective/peggy/v1/submit_bad_signature_evidence\x12`\n\x0cUpdateParams\x12#.injective.peggy.v1.MsgUpdateParams\x1a+.injective.peggy.v1.MsgUpdateParamsResponseBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.msgs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _MSGVALSETCONFIRM._options = None
  _MSGVALSETCONFIRM._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGSENDTOETH.fields_by_name['amount']._options = None
  _MSGSENDTOETH.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGSENDTOETH.fields_by_name['bridge_fee']._options = None
  _MSGSENDTOETH.fields_by_name['bridge_fee']._serialized_options = b'\310\336\037\000'
  _MSGSENDTOETH._options = None
  _MSGSENDTOETH._serialized_options = b'\202\347\260*\006sender'
  _MSGREQUESTBATCH._options = None
  _MSGREQUESTBATCH._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGCONFIRMBATCH._options = None
  _MSGCONFIRMBATCH._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGDEPOSITCLAIM.fields_by_name['amount']._options = None
  _MSGDEPOSITCLAIM.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGDEPOSITCLAIM._options = None
  _MSGDEPOSITCLAIM._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGWITHDRAWCLAIM._options = None
  _MSGWITHDRAWCLAIM._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGERC20DEPLOYEDCLAIM._options = None
  _MSGERC20DEPLOYEDCLAIM._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGCANCELSENDTOETH._options = None
  _MSGCANCELSENDTOETH._serialized_options = b'\202\347\260*\006sender'
  _MSGSUBMITBADSIGNATUREEVIDENCE._options = None
  _MSGSUBMITBADSIGNATUREEVIDENCE._serialized_options = b'\202\347\260*\006sender'
  _MSGVALSETUPDATEDCLAIM.fields_by_name['reward_amount']._options = None
  _MSGVALSETUPDATEDCLAIM.fields_by_name['reward_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MSGVALSETUPDATEDCLAIM._options = None
  _MSGVALSETUPDATEDCLAIM._serialized_options = b'\202\347\260*\014orchestrator'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSG.methods_by_name['ValsetConfirm']._options = None
  _MSG.methods_by_name['ValsetConfirm']._serialized_options = b'\202\323\344\223\002$\"\"/injective/peggy/v1/valset_confirm'
  _MSG.methods_by_name['SendToEth']._options = None
  _MSG.methods_by_name['SendToEth']._serialized_options = b'\202\323\344\223\002!\"\037/injective/peggy/v1/send_to_eth'
  _MSG.methods_by_name['RequestBatch']._options = None
  _MSG.methods_by_name['RequestBatch']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/request_batch'
  _MSG.methods_by_name['ConfirmBatch']._options = None
  _MSG.methods_by_name['ConfirmBatch']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/confirm_batch'
  _MSG.methods_by_name['DepositClaim']._options = None
  _MSG.methods_by_name['DepositClaim']._serialized_options = b'\202\323\344\223\002#\"!/injective/peggy/v1/deposit_claim'
  _MSG.methods_by_name['WithdrawClaim']._options = None
  _MSG.methods_by_name['WithdrawClaim']._serialized_options = b'\202\323\344\223\002$\"\"/injective/peggy/v1/withdraw_claim'
  _MSG.methods_by_name['ValsetUpdateClaim']._options = None
  _MSG.methods_by_name['ValsetUpdateClaim']._serialized_options = b'\202\323\344\223\002*\"(/injective/peggy/v1/valset_updated_claim'
  _MSG.methods_by_name['ERC20DeployedClaim']._options = None
  _MSG.methods_by_name['ERC20DeployedClaim']._serialized_options = b'\202\323\344\223\002*\"(/injective/peggy/v1/erc20_deployed_claim'
  _MSG.methods_by_name['SetOrchestratorAddresses']._options = None
  _MSG.methods_by_name['SetOrchestratorAddresses']._serialized_options = b'\202\323\344\223\002.\",/injective/peggy/v1/set_orchestrator_address'
  _MSG.methods_by_name['CancelSendToEth']._options = None
  _MSG.methods_by_name['CancelSendToEth']._serialized_options = b'\202\323\344\223\002(\"&/injective/peggy/v1/cancel_send_to_eth'
  _MSG.methods_by_name['SubmitBadSignatureEvidence']._options = None
  _MSG.methods_by_name['SubmitBadSignatureEvidence']._serialized_options = b'\202\323\344\223\0023\"1/injective/peggy/v1/submit_bad_signature_evidence'
  _globals['_MSGSETORCHESTRATORADDRESSES']._serialized_start=281
  _globals['_MSGSETORCHESTRATORADDRESSES']._serialized_end=369
  _globals['_MSGSETORCHESTRATORADDRESSESRESPONSE']._serialized_start=371
  _globals['_MSGSETORCHESTRATORADDRESSESRESPONSE']._serialized_end=408
  _globals['_MSGVALSETCONFIRM']._serialized_start=410
  _globals['_MSGVALSETCONFIRM']._serialized_end=524
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_start=526
  _globals['_MSGVALSETCONFIRMRESPONSE']._serialized_end=552
  _globals['_MSGSENDTOETH']._serialized_start=555
  _globals['_MSGSENDTOETH']._serialized_end=718
  _globals['_MSGSENDTOETHRESPONSE']._serialized_start=720
  _globals['_MSGSENDTOETHRESPONSE']._serialized_end=742
  _globals['_MSGREQUESTBATCH']._serialized_start=744
  _globals['_MSGREQUESTBATCH']._serialized_end=817
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_start=819
  _globals['_MSGREQUESTBATCHRESPONSE']._serialized_end=844
  _globals['_MSGCONFIRMBATCH']._serialized_start=847
  _globals['_MSGCONFIRMBATCH']._serialized_end=983
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_start=985
  _globals['_MSGCONFIRMBATCHRESPONSE']._serialized_end=1010
  _globals['_MSGDEPOSITCLAIM']._serialized_start=1013
  _globals['_MSGDEPOSITCLAIM']._serialized_end=1266
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_start=1268
  _globals['_MSGDEPOSITCLAIMRESPONSE']._serialized_end=1293
  _globals['_MSGWITHDRAWCLAIM']._serialized_start=1296
  _globals['_MSGWITHDRAWCLAIM']._serialized_end=1443
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_start=1445
  _globals['_MSGWITHDRAWCLAIMRESPONSE']._serialized_end=1471
  _globals['_MSGERC20DEPLOYEDCLAIM']._serialized_start=1474
  _globals['_MSGERC20DEPLOYEDCLAIM']._serialized_end=1675
  _globals['_MSGERC20DEPLOYEDCLAIMRESPONSE']._serialized_start=1677
  _globals['_MSGERC20DEPLOYEDCLAIMRESPONSE']._serialized_end=1708
  _globals['_MSGCANCELSENDTOETH']._serialized_start=1710
  _globals['_MSGCANCELSENDTOETH']._serialized_end=1783
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_start=1785
  _globals['_MSGCANCELSENDTOETHRESPONSE']._serialized_end=1813
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._serialized_start=1815
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCE']._serialized_end=1933
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE']._serialized_start=1935
  _globals['_MSGSUBMITBADSIGNATUREEVIDENCERESPONSE']._serialized_end=1974
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_start=1977
  _globals['_MSGVALSETUPDATEDCLAIM']._serialized_end=2253
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_start=2255
  _globals['_MSGVALSETUPDATEDCLAIMRESPONSE']._serialized_end=2286
  _globals['_MSGUPDATEPARAMS']._serialized_start=2289
  _globals['_MSGUPDATEPARAMS']._serialized_end=2417
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=2419
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=2444
  _globals['_MSG']._serialized_start=2447
  _globals['_MSG']._serialized_end=4277
# @@protoc_insertion_point(module_scope)



import asyncio
import time
from copy import deepcopy
from decimal import Decimal
from typing import Coroutine, Dict, List, Optional, Tuple, Union

import grpc

from pyinjective.composer import Composer
from pyinjective.proto.injective.stream.v1beta1 import query_pb2 as chain_stream_query
from pyinjective.proto.injective.stream.v1beta1 import query_pb2_grpc as stream_rpc_grpc

from . import constant
from .core.market import BinaryOptionMarket, DerivativeMarket, SpotMarket
from .core.network import Network
from .core.token import Token
from .exceptions import NotFoundError
from .proto.cosmos.auth.v1beta1 import query_pb2 as auth_query
from .proto.cosmos.auth.v1beta1 import query_pb2_grpc as auth_query_grpc
from .proto.cosmos.authz.v1beta1 import query_pb2 as authz_query
from .proto.cosmos.authz.v1beta1 import query_pb2_grpc as authz_query_grpc
from .proto.cosmos.bank.v1beta1 import query_pb2 as bank_query
from .proto.cosmos.bank.v1beta1 import query_pb2_grpc as bank_query_grpc
from .proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
from .proto.cosmos.base.tendermint.v1beta1 import query_pb2 as tendermint_query
from .proto.cosmos.base.tendermint.v1beta1 import query_pb2_grpc as tendermint_query_grpc
from .proto.cosmos.tx.v1beta1 import service_pb2 as tx_service
from .proto.cosmos.tx.v1beta1 import service_pb2_grpc as tx_service_grpc
from .proto.exchange import injective_accounts_rpc_pb2 as exchange_accounts_rpc_pb
from .proto.exchange import injective_accounts_rpc_pb2_grpc as exchange_accounts_rpc_grpc
from .proto.exchange import injective_auction_rpc_pb2 as auction_rpc_pb
from .proto.exchange import injective_auction_rpc_pb2_grpc as auction_rpc_grpc
from .proto.exchange import injective_derivative_exchange_rpc_pb2 as derivative_exchange_rpc_pb
from .proto.exchange import injective_derivative_exchange_rpc_pb2_grpc as derivative_exchange_rpc_grpc
from .proto.exchange import injective_explorer_rpc_pb2 as explorer_rpc_pb
from .proto.exchange import injective_explorer_rpc_pb2_grpc as explorer_rpc_grpc
from .proto.exchange import injective_insurance_rpc_pb2 as insurance_rpc_pb
from .proto.exchange import injective_insurance_rpc_pb2_grpc as insurance_rpc_grpc
from .proto.exchange import injective_meta_rpc_pb2 as exchange_meta_rpc_pb
from .proto.exchange import injective_meta_rpc_pb2_grpc as exchange_meta_rpc_grpc
from .proto.exchange import injective_oracle_rpc_pb2 as oracle_rpc_pb
from .proto.exchange import injective_oracle_rpc_pb2_grpc as oracle_rpc_grpc
from .proto.exchange import injective_portfolio_rpc_pb2 as portfolio_rpc_pb
from .proto.exchange import injective_portfolio_rpc_pb2_grpc as portfolio_rpc_grpc
from .proto.exchange import injective_spot_exchange_rpc_pb2 as spot_exchange_rpc_pb
from .proto.exchange import injective_spot_exchange_rpc_pb2_grpc as spot_exchange_rpc_grpc
from .proto.injective.types.v1beta1 import account_pb2
from .utils.logger import LoggerProvider

DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL = 20  # seconds
DEFAULT_TIMEOUTHEIGHT = 30  # blocks
DEFAULT_SESSION_RENEWAL_OFFSET = 120  # seconds
DEFAULT_BLOCK_TIME = 2  # seconds


class AsyncClient:
    def __init__(
        self,
        network: Network,
        insecure: bool = False,
        credentials=grpc.ssl_channel_credentials(),
    ):
        # the `insecure` parameter is ignored and will be deprecated soon. The value is taken directly from `network`

        self.addr = ""
        self.number = 0
        self.sequence = 0

        self.network = network

        # chain stubs
        self.chain_channel = (
            grpc.aio.secure_channel(network.grpc_endpoint, credentials)
            if (network.use_secure_connection and credentials is not None)
            else grpc.aio.insecure_channel(network.grpc_endpoint)
        )

        self.stubCosmosTendermint = tendermint_query_grpc.ServiceStub(self.chain_channel)
        self.stubAuth = auth_query_grpc.QueryStub(self.chain_channel)
        self.stubAuthz = authz_query_grpc.QueryStub(self.chain_channel)
        self.stubBank = bank_query_grpc.QueryStub(self.chain_channel)
        self.stubTx = tx_service_grpc.ServiceStub(self.chain_channel)

        self.exchange_cookie = ""
        self.timeout_height = 1

        # exchange stubs
        self.exchange_channel = (
            grpc.aio.secure_channel(network.grpc_exchange_endpoint, credentials)
            if (network.use_secure_connection and credentials is not None)
            else grpc.aio.insecure_channel(network.grpc_exchange_endpoint)
        )
        self.stubMeta = exchange_meta_rpc_grpc.InjectiveMetaRPCStub(self.exchange_channel)
        self.stubExchangeAccount = exchange_accounts_rpc_grpc.InjectiveAccountsRPCStub(self.exchange_channel)
        self.stubOracle = oracle_rpc_grpc.InjectiveOracleRPCStub(self.exchange_channel)
        self.stubInsurance = insurance_rpc_grpc.InjectiveInsuranceRPCStub(self.exchange_channel)
        self.stubSpotExchange = spot_exchange_rpc_grpc.InjectiveSpotExchangeRPCStub(self.exchange_channel)
        self.stubDerivativeExchange = derivative_exchange_rpc_grpc.InjectiveDerivativeExchangeRPCStub(
            self.exchange_channel
        )
        self.stubAuction = auction_rpc_grpc.InjectiveAuctionRPCStub(self.exchange_channel)
        self.stubPortfolio = portfolio_rpc_grpc.InjectivePortfolioRPCStub(self.exchange_channel)

        # explorer stubs
        self.explorer_channel = (
            grpc.aio.secure_channel(network.grpc_explorer_endpoint, credentials)
            if (network.use_secure_connection and credentials is not None)
            else grpc.aio.insecure_channel(network.grpc_explorer_endpoint)
        )
        self.stubExplorer = explorer_rpc_grpc.InjectiveExplorerRPCStub(self.explorer_channel)

        self.chain_stream_channel = (
            grpc.aio.secure_channel(network.chain_stream_endpoint, credentials)
            if (network.use_secure_connection and credentials is not None)
            else grpc.aio.insecure_channel(network.chain_stream_endpoint)
        )
        self.chain_stream_stub = stream_rpc_grpc.StreamStub(channel=self.chain_stream_channel)

        self._timeout_height_sync_task = None
        self._initialize_timeout_height_sync_task()

        self._tokens_and_markets_initialization_lock = asyncio.Lock()
        self._tokens_by_denom: Optional[Dict[str, Token]] = None
        self._tokens_by_symbol: Optional[Dict[str, Token]] = None
        self._spot_markets: Optional[Dict[str, SpotMarket]] = None
        self._derivative_markets: Optional[Dict[str, DerivativeMarket]] = None
        self._binary_option_markets: Optional[Dict[str, BinaryOptionMarket]] = None

    async def all_tokens(self) -> Dict[str, Token]:
        if self._tokens_by_symbol is None:
            async with self._tokens_and_markets_initialization_lock:
                if self._tokens_by_symbol is None:
                    await self._initialize_tokens_and_markets()
        return deepcopy(self._tokens_by_symbol)

    async def all_spot_markets(self) -> Dict[str, SpotMarket]:
        if self._spot_markets is None:
            async with self._tokens_and_markets_initialization_lock:
                if self._spot_markets is None:
                    await self._initialize_tokens_and_markets()
        return deepcopy(self._spot_markets)

    async def all_derivative_markets(self) -> Dict[str, DerivativeMarket]:
        if self._derivative_markets is None:
            async with self._tokens_and_markets_initialization_lock:
                if self._derivative_markets is None:
                    await self._initialize_tokens_and_markets()
        return deepcopy(self._derivative_markets)

    async def all_binary_option_markets(self) -> Dict[str, BinaryOptionMarket]:
        if self._binary_option_markets is None:
            async with self._tokens_and_markets_initialization_lock:
                if self._binary_option_markets is None:
                    await self._initialize_tokens_and_markets()
        return deepcopy(self._binary_option_markets)

    def get_sequence(self):
        current_seq = self.sequence
        self.sequence += 1
        return current_seq

    def get_number(self):
        return self.number

    async def get_tx(self, tx_hash):
        return await self.stubTx.GetTx(tx_service.GetTxRequest(hash=tx_hash))

    async def close_exchange_channel(self):
        await self.exchange_channel.close()
        self._cancel_timeout_height_sync_task()

    async def close_chain_channel(self):
        await self.chain_channel.close()
        self._cancel_timeout_height_sync_task()

    async def sync_timeout_height(self):
        try:
            block = await self.get_latest_block()
            self.timeout_height = block.block.header.height + DEFAULT_TIMEOUTHEIGHT
        except Exception as e:
            LoggerProvider().logger_for_class(logging_class=self.__class__).debug(
                f"error while fetching latest block, setting timeout height to 0: {e}"
            )
            self.timeout_height = 0

    # default client methods
    async def get_latest_block(self) -> tendermint_query.GetLatestBlockResponse:
        req = tendermint_query.GetLatestBlockRequest()
        return await self.stubCosmosTendermint.GetLatestBlock(req)

    async def get_account(self, address: str) -> Optional[account_pb2.EthAccount]:
        try:
            metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
            account_any = (
                await self.stubAuth.Account(auth_query.QueryAccountRequest(address=address), metadata=metadata)
            ).account
            account = account_pb2.EthAccount()
            if account_any.Is(account.DESCRIPTOR):
                account_any.Unpack(account)
                self.number = int(account.base_account.account_number)
                self.sequence = int(account.base_account.sequence)
        except Exception as e:
            LoggerProvider().logger_for_class(logging_class=self.__class__).debug(
                f"error while fetching sequence and number {e}"
            )
            return None

    async def get_request_id_by_tx_hash(self, tx_hash: bytes) -> List[int]:
        tx = await self.stubTx.GetTx(tx_service.GetTxRequest(hash=tx_hash))
        request_ids = []
        for tx in tx.tx_response.logs:
            request_event = [event for event in tx.events if event.type == "request" or event.type == "report"]
            if len(request_event) == 1:
                attrs = request_event[0].attributes
                attr_id = [attr for attr in attrs if attr.key == "id"]
                if len(attr_id) == 1:
                    request_id = attr_id[0].value
                    request_ids.append(int(request_id))
        if len(request_ids) == 0:
            raise NotFoundError("Request Id is not found")
        return request_ids

    async def simulate_tx(self, tx_byte: bytes) -> Tuple[Union[abci_type.SimulationResponse, grpc.RpcError], bool]:
        try:
            req = tx_service.SimulateRequest(tx_bytes=tx_byte)
            metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
            return await self.stubTx.Simulate(request=req, metadata=metadata), True
        except grpc.RpcError as err:
            return err, False

    async def send_tx_sync_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_SYNC)
        metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
        result = await self.stubTx.BroadcastTx(request=req, metadata=metadata)
        return result.tx_response

    async def send_tx_async_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_ASYNC)
        metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
        result = await self.stubTx.BroadcastTx(request=req, metadata=metadata)
        return result.tx_response

    async def send_tx_block_mode(self, tx_byte: bytes) -> abci_type.TxResponse:
        req = tx_service.BroadcastTxRequest(tx_bytes=tx_byte, mode=tx_service.BroadcastMode.BROADCAST_MODE_BLOCK)
        metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
        result = await self.stubTx.BroadcastTx(request=req, metadata=metadata)
        return result.tx_response

    async def get_chain_id(self) -> str:
        latest_block = await self.get_latest_block()
        return latest_block.block.header.chain_id

    async def get_grants(self, granter: str, grantee: str, **kwargs):
        return await self.stubAuthz.Grants(
            authz_query.QueryGrantsRequest(
                granter=granter,
                grantee=grantee,
                msg_type_url=kwargs.get("msg_type_url"),
            )
        )

    async def get_bank_balances(self, address: str):
        return await self.stubBank.AllBalances(bank_query.QueryAllBalancesRequest(address=address))

    async def get_bank_balance(self, address: str, denom: str):
        return await self.stubBank.Balance(bank_query.QueryBalanceRequest(address=address, denom=denom))

    # Injective Exchange client methods

    # Auction RPC

    async def get_auction(self, bid_round: int):
        req = auction_rpc_pb.AuctionEndpointRequest(round=bid_round)
        return await self.stubAuction.AuctionEndpoint(req)

    async def get_auctions(self):
        req = auction_rpc_pb.AuctionsRequest()
        return await self.stubAuction.Auctions(req)

    async def stream_bids(self):
        req = auction_rpc_pb.StreamBidsRequest()
        return self.stubAuction.StreamBids(req)

    # Meta RPC

    async def ping(self):
        req = exchange_meta_rpc_pb.PingRequest()
        return await self.stubMeta.Ping(req)

    async def version(self):
        req = exchange_meta_rpc_pb.VersionRequest()
        return await self.stubMeta.Version(req)

    async def info(self):
        req = exchange_meta_rpc_pb.InfoRequest(
            timestamp=int(time.time() * 1000),
        )
        return await self.stubMeta.Info(req)

    async def stream_keepalive(self):
        req = exchange_meta_rpc_pb.StreamKeepaliveRequest()
        return self.stubMeta.StreamKeepalive(req)

    # Explorer RPC

    async def get_tx_by_hash(self, tx_hash: str):
        req = explorer_rpc_pb.GetTxByTxHashRequest(hash=tx_hash)
        return await self.stubExplorer.GetTxByTxHash(req)

    async def get_account_txs(self, address: str, **kwargs):
        req = explorer_rpc_pb.GetAccountTxsRequest(
            address=address,
            before=kwargs.get("before"),
            after=kwargs.get("after"),
            limit=kwargs.get("limit"),
            skip=kwargs.get("skip"),
            type=kwargs.get("type"),
            module=kwargs.get("module"),
        )
        return await self.stubExplorer.GetAccountTxs(req)

    async def get_blocks(self, **kwargs):
        req = explorer_rpc_pb.GetBlocksRequest(
            before=kwargs.get("before"),
            after=kwargs.get("after"),
            limit=kwargs.get("limit"),
        )
        return await self.stubExplorer.GetBlocks(req)

    async def get_block(self, block_height: str):
        req = explorer_rpc_pb.GetBlockRequest(id=block_height)
        return await self.stubExplorer.GetBlock(req)

    async def get_txs(self, **kwargs):
        req = explorer_rpc_pb.GetTxsRequest(
            before=kwargs.get("before"),
            after=kwargs.get("after"),
            limit=kwargs.get("limit"),
            skip=kwargs.get("skip"),
            type=kwargs.get("type"),
            module=kwargs.get("module"),
        )
        return await self.stubExplorer.GetTxs(req)

    async def stream_txs(self):
        req = explorer_rpc_pb.StreamTxsRequest()
        return self.stubExplorer.StreamTxs(req)

    async def stream_blocks(self):
        req = explorer_rpc_pb.StreamBlocksRequest()
        return self.stubExplorer.StreamBlocks(req)

    async def get_peggy_deposits(self, **kwargs):
        req = explorer_rpc_pb.GetPeggyDepositTxsRequest(
            sender=kwargs.get("sender"),
            receiver=kwargs.get("receiver"),
            limit=kwargs.get("limit"),
            skip=kwargs.get("skip"),
        )
        return await self.stubExplorer.GetPeggyDepositTxs(req)

    async def get_peggy_withdrawals(self, **kwargs):
        req = explorer_rpc_pb.GetPeggyWithdrawalTxsRequest(
            sender=kwargs.get("sender"),
            receiver=kwargs.get("receiver"),
            limit=kwargs.get("limit"),
            skip=kwargs.get("skip"),
        )
        return await self.stubExplorer.GetPeggyWithdrawalTxs(req)

    async def get_ibc_transfers(self, **kwargs):
        req = explorer_rpc_pb.GetIBCTransferTxsRequest(
            sender=kwargs.get("sender"),
            receiver=kwargs.get("receiver"),
            src_channel=kwargs.get("src_channel"),
            src_port=kwargs.get("src_port"),
            dest_channel=kwargs.get("dest_channel"),
            dest_port=kwargs.get("dest_port"),
            limit=kwargs.get("limit"),
            skip=kwargs.get("skip"),
        )
        return await self.stubExplorer.GetIBCTransferTxs(req)

    # AccountsRPC

    async def stream_subaccount_balance(self, subaccount_id: str, **kwargs):
        req = exchange_accounts_rpc_pb.StreamSubaccountBalanceRequest(
            subaccount_id=subaccount_id, denoms=kwargs.get("denoms")
        )
        return self.stubExchangeAccount.StreamSubaccountBalance(req)

    async def get_subaccount_balance(self, subaccount_id: str, denom: str):
        req = exchange_accounts_rpc_pb.SubaccountBalanceEndpointRequest(subaccount_id=subaccount_id, denom=denom)
        return await self.stubExchangeAccount.SubaccountBalanceEndpoint(req)

    async def get_subaccount_list(self, account_address: str):
        req = exchange_accounts_rpc_pb.SubaccountsListRequest(account_address=account_address)
        return await self.stubExchangeAccount.SubaccountsList(req)

    async def get_subaccount_balances_list(self, subaccount_id: str, **kwargs):
        req = exchange_accounts_rpc_pb.SubaccountBalancesListRequest(
            subaccount_id=subaccount_id, denoms=kwargs.get("denoms")
        )
        return await self.stubExchangeAccount.SubaccountBalancesList(req)

    async def get_subaccount_history(self, subaccount_id: str, **kwargs):
        req = exchange_accounts_rpc_pb.SubaccountHistoryRequest(
            subaccount_id=subaccount_id,
            denom=kwargs.get("denom"),
            transfer_types=kwargs.get("transfer_types"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            end_time=kwargs.get("end_time"),
        )
        return await self.stubExchangeAccount.SubaccountHistory(req)

    async def get_subaccount_order_summary(self, subaccount_id: str, **kwargs):
        req = exchange_accounts_rpc_pb.SubaccountOrderSummaryRequest(
            subaccount_id=subaccount_id,
            order_direction=kwargs.get("order_direction"),
            market_id=kwargs.get("market_id"),
        )
        return await self.stubExchangeAccount.SubaccountOrderSummary(req)

    async def get_order_states(self, **kwargs):
        req = exchange_accounts_rpc_pb.OrderStatesRequest(
            spot_order_hashes=kwargs.get("spot_order_hashes"),
            derivative_order_hashes=kwargs.get("derivative_order_hashes"),
        )
        return await self.stubExchangeAccount.OrderStates(req)

    async def get_portfolio(self, account_address: str):
        req = exchange_accounts_rpc_pb.PortfolioRequest(account_address=account_address)
        return await self.stubExchangeAccount.Portfolio(req)

    async def get_rewards(self, **kwargs):
        req = exchange_accounts_rpc_pb.RewardsRequest(
            account_address=kwargs.get("account_address"), epoch=kwargs.get("epoch")
        )
        return await self.stubExchangeAccount.Rewards(req)

    # OracleRPC

    async def stream_oracle_prices(self, base_symbol: str, quote_symbol: str, oracle_type: str):
        req = oracle_rpc_pb.StreamPricesRequest(
            base_symbol=base_symbol, quote_symbol=quote_symbol, oracle_type=oracle_type
        )
        return self.stubOracle.StreamPrices(req)

    async def get_oracle_prices(
        self,
        base_symbol: str,
        quote_symbol: str,
        oracle_type: str,
        oracle_scale_factor: int,
    ):
        req = oracle_rpc_pb.PriceRequest(
            base_symbol=base_symbol,
            quote_symbol=quote_symbol,
            oracle_type=oracle_type,
            oracle_scale_factor=oracle_scale_factor,
        )
        return await self.stubOracle.Price(req)

    async def get_oracle_list(self):
        req = oracle_rpc_pb.OracleListRequest()
        return await self.stubOracle.OracleList(req)

    # InsuranceRPC

    async def get_insurance_funds(self):
        req = insurance_rpc_pb.FundsRequest()
        return await self.stubInsurance.Funds(req)

    async def get_redemptions(self, **kwargs):
        req = insurance_rpc_pb.RedemptionsRequest(
            redeemer=kwargs.get("redeemer"),
            redemption_denom=kwargs.get("redemption_denom"),
            status=kwargs.get("status"),
        )
        return await self.stubInsurance.Redemptions(req)

    # SpotRPC

    async def get_spot_market(self, market_id: str):
        req = spot_exchange_rpc_pb.MarketRequest(market_id=market_id)
        return await self.stubSpotExchange.Market(req)

    async def get_spot_markets(self, **kwargs):
        req = spot_exchange_rpc_pb.MarketsRequest(
            market_status=kwargs.get("market_status"),
            base_denom=kwargs.get("base_denom"),
            quote_denom=kwargs.get("quote_denom"),
        )
        return await self.stubSpotExchange.Markets(req)

    async def stream_spot_markets(self, **kwargs):
        req = spot_exchange_rpc_pb.StreamMarketsRequest(market_ids=kwargs.get("market_ids"))
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamMarkets(request=req, metadata=metadata)

    async def get_spot_orderbookV2(self, market_id: str):
        req = spot_exchange_rpc_pb.OrderbookV2Request(market_id=market_id)
        return await self.stubSpotExchange.OrderbookV2(req)

    async def get_spot_orderbooksV2(self, market_ids: List):
        req = spot_exchange_rpc_pb.OrderbooksV2Request(market_ids=market_ids)
        return await self.stubSpotExchange.OrderbooksV2(req)

    async def get_spot_orders(self, market_id: str, **kwargs):
        req = spot_exchange_rpc_pb.OrdersRequest(
            market_id=market_id,
            order_side=kwargs.get("order_side"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            include_inactive=kwargs.get("include_inactive"),
            subaccount_total_orders=kwargs.get("subaccount_total_orders"),
            trade_id=kwargs.get("trade_id"),
            cid=kwargs.get("cid"),
        )
        return await self.stubSpotExchange.Orders(req)

    async def get_historical_spot_orders(self, market_id: Optional[str] = None, **kwargs):
        market_ids = kwargs.get("market_ids", [])
        if market_id is not None:
            market_ids.append(market_id)
        order_types = kwargs.get("order_types", [])
        order_type = kwargs.get("order_type")
        if order_type is not None:
            order_types.append(market_id)
        req = spot_exchange_rpc_pb.OrdersHistoryRequest(
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            order_types=order_types,
            direction=kwargs.get("direction"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            state=kwargs.get("state"),
            execution_types=kwargs.get("execution_types", []),
            market_ids=market_ids,
            trade_id=kwargs.get("trade_id"),
            active_markets_only=kwargs.get("active_markets_only"),
            cid=kwargs.get("cid"),
        )
        return await self.stubSpotExchange.OrdersHistory(req)

    async def get_spot_trades(self, **kwargs):
        req = spot_exchange_rpc_pb.TradesRequest(
            market_id=kwargs.get("market_id"),
            execution_side=kwargs.get("execution_side"),
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            subaccount_ids=kwargs.get("subaccount_ids"),
            execution_types=kwargs.get("execution_types"),
            trade_id=kwargs.get("trade_id"),
            account_address=kwargs.get("account_address"),
            cid=kwargs.get("cid"),
        )
        return await self.stubSpotExchange.Trades(req)

    async def stream_spot_orderbook_snapshot(self, market_ids: List[str]):
        req = spot_exchange_rpc_pb.StreamOrderbookV2Request(market_ids=market_ids)
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamOrderbookV2(request=req, metadata=metadata)

    async def stream_spot_orderbook_update(self, market_ids: List[str]):
        req = spot_exchange_rpc_pb.StreamOrderbookUpdateRequest(market_ids=market_ids)
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamOrderbookUpdate(request=req, metadata=metadata)

    async def stream_spot_orders(self, market_id: str, **kwargs):
        req = spot_exchange_rpc_pb.StreamOrdersRequest(
            market_id=market_id,
            order_side=kwargs.get("order_side"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            include_inactive=kwargs.get("include_inactive"),
            subaccount_total_orders=kwargs.get("subaccount_total_orders"),
            trade_id=kwargs.get("trade_id"),
            cid=kwargs.get("cid"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamOrders(request=req, metadata=metadata)

    async def stream_historical_spot_orders(self, market_id: str, **kwargs):
        req = spot_exchange_rpc_pb.StreamOrdersHistoryRequest(
            market_id=market_id,
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            order_types=kwargs.get("order_types"),
            state=kwargs.get("state"),
            execution_types=kwargs.get("execution_types"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamOrdersHistory(request=req, metadata=metadata)

    async def stream_historical_derivative_orders(self, market_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.StreamOrdersHistoryRequest(
            market_id=market_id,
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            order_types=kwargs.get("order_types"),
            state=kwargs.get("state"),
            execution_types=kwargs.get("execution_types"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamOrdersHistory(request=req, metadata=metadata)

    async def stream_spot_trades(self, **kwargs):
        req = spot_exchange_rpc_pb.StreamTradesRequest(
            market_id=kwargs.get("market_id"),
            execution_side=kwargs.get("execution_side"),
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            subaccount_ids=kwargs.get("subaccount_ids"),
            execution_types=kwargs.get("execution_types"),
            trade_id=kwargs.get("trade_id"),
            account_address=kwargs.get("account_address"),
            cid=kwargs.get("cid"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubSpotExchange.StreamTrades(request=req, metadata=metadata)

    async def get_spot_subaccount_orders(self, subaccount_id: str, **kwargs):
        req = spot_exchange_rpc_pb.SubaccountOrdersListRequest(
            subaccount_id=subaccount_id,
            market_id=kwargs.get("market_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubSpotExchange.SubaccountOrdersList(req)

    async def get_spot_subaccount_trades(self, subaccount_id: str, **kwargs):
        req = spot_exchange_rpc_pb.SubaccountTradesListRequest(
            subaccount_id=subaccount_id,
            market_id=kwargs.get("market_id"),
            execution_type=kwargs.get("execution_type"),
            direction=kwargs.get("direction"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubSpotExchange.SubaccountTradesList(req)

    # DerivativeRPC

    async def get_derivative_market(self, market_id: str):
        req = derivative_exchange_rpc_pb.MarketRequest(market_id=market_id)
        return await self.stubDerivativeExchange.Market(req)

    async def get_derivative_markets(self, **kwargs):
        req = derivative_exchange_rpc_pb.MarketsRequest(
            market_status=kwargs.get("market_status"),
            quote_denom=kwargs.get("quote_denom"),
        )
        return await self.stubDerivativeExchange.Markets(req)

    async def stream_derivative_markets(self, **kwargs):
        req = derivative_exchange_rpc_pb.StreamMarketRequest(market_ids=kwargs.get("market_ids"))
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamMarket(request=req, metadata=metadata)

    async def get_derivative_orderbook(self, market_id: str):
        req = derivative_exchange_rpc_pb.OrderbookV2Request(market_id=market_id)
        return await self.stubDerivativeExchange.OrderbookV2(req)

    async def get_derivative_orderbooks(self, market_ids: List):
        req = derivative_exchange_rpc_pb.OrderbooksV2Request(market_ids=market_ids)
        return await self.stubDerivativeExchange.OrderbooksV2(req)

    async def get_derivative_orderbooksV2(self, market_ids: List):
        req = derivative_exchange_rpc_pb.OrderbooksV2Request(market_ids=market_ids)
        return await self.stubDerivativeExchange.OrderbooksV2(req)

    async def get_derivative_orders(self, market_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.OrdersRequest(
            market_id=market_id,
            order_side=kwargs.get("order_side"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            is_conditional=kwargs.get("is_conditional"),
            order_type=kwargs.get("order_type"),
            include_inactive=kwargs.get("include_inactive"),
            subaccount_total_orders=kwargs.get("subaccount_total_orders"),
            trade_id=kwargs.get("trade_id"),
            cid=kwargs.get("cid"),
        )
        return await self.stubDerivativeExchange.Orders(req)

    async def get_historical_derivative_orders(self, market_id: Optional[str] = None, **kwargs):
        market_ids = kwargs.get("market_ids", [])
        if market_id is not None:
            market_ids.append(market_id)
        order_types = kwargs.get("order_types", [])
        order_type = kwargs.get("order_type")
        if order_type is not None:
            order_types.append(market_id)
        req = derivative_exchange_rpc_pb.OrdersHistoryRequest(
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            order_types=order_types,
            direction=kwargs.get("direction"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            is_conditional=kwargs.get("is_conditional"),
            state=kwargs.get("state"),
            execution_types=kwargs.get("execution_types", []),
            market_ids=market_ids,
            trade_id=kwargs.get("trade_id"),
            active_markets_only=kwargs.get("active_markets_only"),
            cid=kwargs.get("cid"),
        )
        return await self.stubDerivativeExchange.OrdersHistory(req)

    async def get_derivative_trades(self, **kwargs):
        req = derivative_exchange_rpc_pb.TradesRequest(
            market_id=kwargs.get("market_id"),
            execution_side=kwargs.get("execution_side"),
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            subaccount_ids=kwargs.get("subaccount_ids"),
            execution_types=kwargs.get("execution_types"),
            trade_id=kwargs.get("trade_id"),
            account_address=kwargs.get("account_address"),
            cid=kwargs.get("cid"),
        )
        return await self.stubDerivativeExchange.Trades(req)

    async def stream_derivative_orderbook_snapshot(self, market_ids: List[str]):
        req = derivative_exchange_rpc_pb.StreamOrderbookV2Request(market_ids=market_ids)
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamOrderbookV2(request=req, metadata=metadata)

    async def stream_derivative_orderbook_update(self, market_ids: List[str]):
        req = derivative_exchange_rpc_pb.StreamOrderbookUpdateRequest(market_ids=market_ids)
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamOrderbookUpdate(request=req, metadata=metadata)

    async def stream_derivative_orders(self, market_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.StreamOrdersRequest(
            market_id=market_id,
            execution_side=kwargs.get("execution_side"),
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            subaccount_ids=kwargs.get("subaccount_ids"),
            execution_types=kwargs.get("execution_types"),
            trade_id=kwargs.get("trade_id"),
            account_address=kwargs.get("account_address"),
            cid=kwargs.get("cid"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamOrders(request=req, metadata=metadata)

    async def stream_derivative_trades(self, **kwargs):
        req = derivative_exchange_rpc_pb.StreamTradesRequest(
            market_id=kwargs.get("market_id"),
            execution_side=kwargs.get("execution_side"),
            direction=kwargs.get("direction"),
            subaccount_id=kwargs.get("subaccount_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            start_time=kwargs.get("start_time"),
            end_time=kwargs.get("end_time"),
            market_ids=kwargs.get("market_ids"),
            subaccount_ids=kwargs.get("subaccount_ids"),
            execution_types=kwargs.get("execution_types"),
            trade_id=kwargs.get("trade_id"),
            account_address=kwargs.get("account_address"),
            cid=kwargs.get("cid"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamTrades(request=req, metadata=metadata)

    async def get_derivative_positions(self, **kwargs):
        req = derivative_exchange_rpc_pb.PositionsRequest(
            market_id=kwargs.get("market_id"),
            market_ids=kwargs.get("market_ids"),
            subaccount_id=kwargs.get("subaccount_id"),
            direction=kwargs.get("direction"),
            subaccount_total_positions=kwargs.get("subaccount_total_positions"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.Positions(req)

    async def stream_derivative_positions(self, **kwargs):
        req = derivative_exchange_rpc_pb.StreamPositionsRequest(
            market_id=kwargs.get("market_id"),
            market_ids=kwargs.get("market_ids"),
            subaccount_id=kwargs.get("subaccount_id"),
            subaccount_ids=kwargs.get("subaccount_ids"),
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubDerivativeExchange.StreamPositions(request=req, metadata=metadata)

    async def get_derivative_liquidable_positions(self, **kwargs):
        req = derivative_exchange_rpc_pb.LiquidablePositionsRequest(
            market_id=kwargs.get("market_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.LiquidablePositions(req)

    async def get_derivative_subaccount_orders(self, subaccount_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.SubaccountOrdersListRequest(
            subaccount_id=subaccount_id,
            market_id=kwargs.get("market_id"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.SubaccountOrdersList(req)

    async def get_derivative_subaccount_trades(self, subaccount_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.SubaccountTradesListRequest(
            subaccount_id=subaccount_id,
            market_id=kwargs.get("market_id"),
            execution_type=kwargs.get("execution_type"),
            direction=kwargs.get("direction"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.SubaccountTradesList(req)

    async def get_funding_payments(self, subaccount_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.FundingPaymentsRequest(
            subaccount_id=subaccount_id,
            market_id=kwargs.get("market_id"),
            market_ids=kwargs.get("market_ids"),
            skip=kwargs.get("skip"),
            end_time=kwargs.get("end_time"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.FundingPayments(req)

    async def get_funding_rates(self, market_id: str, **kwargs):
        req = derivative_exchange_rpc_pb.FundingRatesRequest(
            market_id=market_id,
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
            end_time=kwargs.get("end_time"),
        )
        return await self.stubDerivativeExchange.FundingRates(req)

    async def get_binary_options_markets(self, **kwargs):
        req = derivative_exchange_rpc_pb.BinaryOptionsMarketsRequest(
            market_status=kwargs.get("market_status"),
            quote_denom=kwargs.get("quote_denom"),
            skip=kwargs.get("skip"),
            limit=kwargs.get("limit"),
        )
        return await self.stubDerivativeExchange.BinaryOptionsMarkets(req)

    async def get_binary_options_market(self, market_id: str):
        req = derivative_exchange_rpc_pb.BinaryOptionsMarketRequest(market_id=market_id)
        return await self.stubDerivativeExchange.BinaryOptionsMarket(req)

    # PortfolioRPC

    async def get_account_portfolio(self, account_address: str):
        req = portfolio_rpc_pb.AccountPortfolioRequest(account_address=account_address)
        return await self.stubPortfolio.AccountPortfolio(req)

    async def stream_account_portfolio(self, account_address: str, **kwargs):
        req = portfolio_rpc_pb.StreamAccountPortfolioRequest(
            account_address=account_address, subaccount_id=kwargs.get("subaccount_id"), type=kwargs.get("type")
        )
        metadata = await self.network.exchange_metadata(
            metadata_query_provider=self._exchange_cookie_metadata_requestor
        )
        return self.stubPortfolio.StreamAccountPortfolio(request=req, metadata=metadata)

    async def chain_stream(
        self,
        bank_balances_filter: Optional[chain_stream_query.BankBalancesFilter] = None,
        subaccount_deposits_filter: Optional[chain_stream_query.SubaccountDepositsFilter] = None,
        spot_trades_filter: Optional[chain_stream_query.TradesFilter] = None,
        derivative_trades_filter: Optional[chain_stream_query.TradesFilter] = None,
        spot_orders_filter: Optional[chain_stream_query.OrdersFilter] = None,
        derivative_orders_filter: Optional[chain_stream_query.OrdersFilter] = None,
        spot_orderbooks_filter: Optional[chain_stream_query.OrderbookFilter] = None,
        derivative_orderbooks_filter: Optional[chain_stream_query.OrderbookFilter] = None,
        positions_filter: Optional[chain_stream_query.PositionsFilter] = None,
        oracle_price_filter: Optional[chain_stream_query.OraclePriceFilter] = None,
    ):
        request = chain_stream_query.StreamRequest(
            bank_balances_filter=bank_balances_filter,
            subaccount_deposits_filter=subaccount_deposits_filter,
            spot_trades_filter=spot_trades_filter,
            derivative_trades_filter=derivative_trades_filter,
            spot_orders_filter=spot_orders_filter,
            derivative_orders_filter=derivative_orders_filter,
            spot_orderbooks_filter=spot_orderbooks_filter,
            derivative_orderbooks_filter=derivative_orderbooks_filter,
            positions_filter=positions_filter,
            oracle_price_filter=oracle_price_filter,
        )
        metadata = await self.network.chain_metadata(metadata_query_provider=self._chain_cookie_metadata_requestor)
        return self.chain_stream_stub.Stream(request=request, metadata=metadata)

    async def composer(self):
        return Composer(
            network=self.network.string(),
            spot_markets=await self.all_spot_markets(),
            derivative_markets=await self.all_derivative_markets(),
            binary_option_markets=await self.all_binary_option_markets(),
            tokens=await self.all_tokens(),
        )

    async def _initialize_tokens_and_markets(self):
        spot_markets = dict()
        derivative_markets = dict()
        binary_option_markets = dict()
        tokens_by_symbol = dict()
        tokens_by_denom = dict()
        markets_info = (await self.get_spot_markets(market_status="active")).markets
        valid_markets = (
            market_info
            for market_info in markets_info
            if len(market_info.base_token_meta.SerializeToString()) > 0
            and len(market_info.quote_token_meta.SerializeToString()) > 0
        )

        for market_info in valid_markets:
            if "/" in market_info.ticker:
                base_token_symbol, quote_token_symbol = market_info.ticker.split(constant.TICKER_TOKENS_SEPARATOR)
            else:
                base_token_symbol = market_info.base_token_meta.symbol
                quote_token_symbol = market_info.quote_token_meta.symbol

            base_token = self._token_representation(
                symbol=base_token_symbol,
                token_meta=market_info.base_token_meta,
                denom=market_info.base_denom,
                tokens_by_denom=tokens_by_denom,
                tokens_by_symbol=tokens_by_symbol,
            )
            quote_token = self._token_representation(
                symbol=quote_token_symbol,
                token_meta=market_info.quote_token_meta,
                denom=market_info.quote_denom,
                tokens_by_denom=tokens_by_denom,
                tokens_by_symbol=tokens_by_symbol,
            )

            market = SpotMarket(
                id=market_info.market_id,
                status=market_info.market_status,
                ticker=market_info.ticker,
                base_token=base_token,
                quote_token=quote_token,
                maker_fee_rate=Decimal(market_info.maker_fee_rate),
                taker_fee_rate=Decimal(market_info.taker_fee_rate),
                service_provider_fee=Decimal(market_info.service_provider_fee),
                min_price_tick_size=Decimal(market_info.min_price_tick_size),
                min_quantity_tick_size=Decimal(market_info.min_quantity_tick_size),
            )

            spot_markets[market.id] = market

        markets_info = (await self.get_derivative_markets(market_status="active")).markets
        valid_markets = (
            market_info for market_info in markets_info if len(market_info.quote_token_meta.SerializeToString()) > 0
        )
        for market_info in valid_markets:
            quote_token_symbol = market_info.quote_token_meta.symbol

            quote_token = self._token_representation(
                symbol=quote_token_symbol,
                token_meta=market_info.quote_token_meta,
                denom=market_info.quote_denom,
                tokens_by_denom=tokens_by_denom,
                tokens_by_symbol=tokens_by_symbol,
            )

            market = DerivativeMarket(
                id=market_info.market_id,
                status=market_info.market_status,
                ticker=market_info.ticker,
                oracle_base=market_info.oracle_base,
                oracle_quote=market_info.oracle_quote,
                oracle_type=market_info.oracle_type,
                oracle_scale_factor=market_info.oracle_scale_factor,
                initial_margin_ratio=Decimal(market_info.initial_margin_ratio),
                maintenance_margin_ratio=Decimal(market_info.maintenance_margin_ratio),
                quote_token=quote_token,
                maker_fee_rate=Decimal(market_info.maker_fee_rate),
                taker_fee_rate=Decimal(market_info.taker_fee_rate),
                service_provider_fee=Decimal(market_info.service_provider_fee),
                min_price_tick_size=Decimal(market_info.min_price_tick_size),
                min_quantity_tick_size=Decimal(market_info.min_quantity_tick_size),
            )

            derivative_markets[market.id] = market

        markets_info = (await self.get_binary_options_markets()).markets
        for market_info in markets_info:
            quote_token = tokens_by_denom.get(market_info.quote_denom, None)

            market = BinaryOptionMarket(
                id=market_info.market_id,
                status=market_info.market_status,
                ticker=market_info.ticker,
                oracle_symbol=market_info.oracle_symbol,
                oracle_provider=market_info.oracle_provider,
                oracle_type=market_info.oracle_type,
                oracle_scale_factor=market_info.oracle_scale_factor,
                expiration_timestamp=market_info.expiration_timestamp,
                settlement_timestamp=market_info.settlement_timestamp,
                quote_token=quote_token,
                maker_fee_rate=Decimal(market_info.maker_fee_rate),
                taker_fee_rate=Decimal(market_info.taker_fee_rate),
                service_provider_fee=Decimal(market_info.service_provider_fee),
                min_price_tick_size=Decimal(market_info.min_price_tick_size),
                min_quantity_tick_size=Decimal(market_info.min_quantity_tick_size),
            )

            binary_option_markets[market.id] = market

        self._tokens_by_denom = tokens_by_denom
        self._tokens_by_symbol = tokens_by_symbol
        self._spot_markets = spot_markets
        self._derivative_markets = derivative_markets
        self._binary_option_markets = binary_option_markets

    def _token_representation(
        self,
        symbol: str,
        token_meta,
        denom: str,
        tokens_by_denom: Dict[str, Token],
        tokens_by_symbol: Dict[str, Token],
    ) -> Token:
        if denom not in tokens_by_denom:
            unique_symbol = denom
            for symbol_candidate in [symbol, token_meta.symbol, token_meta.name]:
                if symbol_candidate not in tokens_by_symbol:
                    unique_symbol = symbol_candidate
                    break

            token = Token(
                name=token_meta.name,
                symbol=symbol,
                denom=denom,
                address=token_meta.address,
                decimals=token_meta.decimals,
                logo=token_meta.logo,
                updated=token_meta.updated_at,
            )

            tokens_by_denom[denom] = token
            tokens_by_symbol[unique_symbol] = token

        return tokens_by_denom[denom]

    def _chain_cookie_metadata_requestor(self) -> Coroutine:
        request = tendermint_query.GetLatestBlockRequest()
        return self.stubCosmosTendermint.GetLatestBlock(request).initial_metadata()

    def _exchange_cookie_metadata_requestor(self) -> Coroutine:
        request = exchange_meta_rpc_pb.VersionRequest()
        return self.stubMeta.Version(request).initial_metadata()

    def _initialize_timeout_height_sync_task(self):
        self._cancel_timeout_height_sync_task()
        self._timeout_height_sync_task = asyncio.get_event_loop().create_task(self._timeout_height_sync_process())

    async def _timeout_height_sync_process(self):
        while True:
            await self.sync_timeout_height()
            await asyncio.sleep(DEFAULT_TIMEOUTHEIGHT_SYNC_INTERVAL)

    def _cancel_timeout_height_sync_task(self):
        if self._timeout_height_sync_task is not None:
            self._timeout_height_sync_task.cancel()
        self._timeout_height_sync_task = None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/genesis.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$cosmos/staking/v1beta1/staking.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xa5\x04\n\x0cGenesisState\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12M\n\x10last_total_power\x18\x02 \x01(\x0c\x42\x33\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xa8\xe7\xb0*\x01\x12T\n\x15last_validator_powers\x18\x03 \x03(\x0b\x32*.cosmos.staking.v1beta1.LastValidatorPowerB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12@\n\nvalidators\x18\x04 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x42\n\x0b\x64\x65legations\x18\x05 \x03(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12U\n\x15unbonding_delegations\x18\x06 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x46\n\rredelegations\x18\x07 \x03(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x10\n\x08\x65xported\x18\x08 \x01(\x08\"X\n\x12LastValidatorPower\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05power\x18\x02 \x01(\x03:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['last_total_power']._options = None
  _GENESISSTATE.fields_by_name['last_total_power']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\250\347\260*\001'
  _GENESISSTATE.fields_by_name['last_validator_powers']._options = None
  _GENESISSTATE.fields_by_name['last_validator_powers']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['validators']._options = None
  _GENESISSTATE.fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['delegations']._options = None
  _GENESISSTATE.fields_by_name['delegations']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['unbonding_delegations']._options = None
  _GENESISSTATE.fields_by_name['unbonding_delegations']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['redelegations']._options = None
  _GENESISSTATE.fields_by_name['redelegations']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _LASTVALIDATORPOWER.fields_by_name['address']._options = None
  _LASTVALIDATORPOWER.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _LASTVALIDATORPOWER._options = None
  _LASTVALIDATORPOWER._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=171
  _globals['_GENESISSTATE']._serialized_end=720
  _globals['_LASTVALIDATORPOWER']._serialized_start=722
  _globals['_LASTVALIDATORPOWER']._serialized_end=810
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/nft.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/nft/v1beta1/nft.proto\x12\x12\x63osmos.nft.v1beta1\x1a\x19google/protobuf/any.proto\"\x89\x01\n\x05\x43lass\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\x12\x10\n\x08uri_hash\x18\x06 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\"f\n\x03NFT\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08uri_hash\x18\x04 \x01(\t\x12\"\n\x04\x64\x61ta\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyB$Z\"github.com/cosmos/cosmos-sdk/x/nftb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.nft_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/x/nft'
  _globals['_CLASS']._serialized_start=80
  _globals['_CLASS']._serialized_end=217
  _globals['_NFT']._serialized_start=219
  _globals['_NFT']._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/wasmx/v1/events.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\x1a\x14gogoproto/gogo.proto\"r\n\x16\x45ventContractExecution\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\x0c\x12\x13\n\x0bother_error\x18\x03 \x01(\t\x12\x17\n\x0f\x65xecution_error\x18\x04 \x01(\t\"\xf9\x01\n\x17\x45ventContractRegistered\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x11\n\tgas_price\x18\x03 \x01(\x04\x12\x1b\n\x13should_pin_contract\x18\x04 \x01(\x08\x12\x1c\n\x14is_migration_allowed\x18\x05 \x01(\x08\x12\x0f\n\x07\x63ode_id\x18\x06 \x01(\x04\x12\x15\n\radmin_address\x18\x07 \x01(\t\x12\x17\n\x0fgranter_address\x18\x08 \x01(\t\x12\x35\n\x0c\x66unding_mode\x18\t \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingMode\"5\n\x19\x45ventContractDeregistered\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _globals['_EVENTCONTRACTEXECUTION']._serialized_start=144
  _globals['_EVENTCONTRACTEXECUTION']._serialized_end=258
  _globals['_EVENTCONTRACTREGISTERED']._serialized_start=261
  _globals['_EVENTCONTRACTREGISTERED']._serialized_end=510
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_start=512
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_end=565
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.wasmx.v1 import tx_pb2 as injective_dot_wasmx_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the wasmx Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateRegistryContractParams = channel.unary_unary(
                '/injective.wasmx.v1.Msg/UpdateRegistryContractParams',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContract.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContractResponse.FromString,
                )
        self.ActivateRegistryContract = channel.unary_unary(
                '/injective.wasmx.v1.Msg/ActivateRegistryContract',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContract.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContractResponse.FromString,
                )
        self.DeactivateRegistryContract = channel.unary_unary(
                '/injective.wasmx.v1.Msg/DeactivateRegistryContract',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContract.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContractResponse.FromString,
                )
        self.ExecuteContractCompat = channel.unary_unary(
                '/injective.wasmx.v1.Msg/ExecuteContractCompat',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompat.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompatResponse.FromString,
                )
        self.UpdateParams = channel.unary_unary(
                '/injective.wasmx.v1.Msg/UpdateParams',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                )
        self.RegisterContract = channel.unary_unary(
                '/injective.wasmx.v1.Msg/RegisterContract',
                request_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContract.SerializeToString,
                response_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContractResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the wasmx Msg service.
    """

    def UpdateRegistryContractParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateRegistryContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateRegistryContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteContractCompat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateRegistryContractParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRegistryContractParams,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContract.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContractResponse.SerializeToString,
            ),
            'ActivateRegistryContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateRegistryContract,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContract.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContractResponse.SerializeToString,
            ),
            'DeactivateRegistryContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateRegistryContract,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContract.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContractResponse.SerializeToString,
            ),
            'ExecuteContractCompat': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteContractCompat,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompat.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompatResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'RegisterContract': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterContract,
                    request_deserializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContract.FromString,
                    response_serializer=injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContractResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.wasmx.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the wasmx Msg service.
    """

    @staticmethod
    def UpdateRegistryContractParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/UpdateRegistryContractParams',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContract.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateRegistryContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/ActivateRegistryContract',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContract.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgActivateContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeactivateRegistryContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/DeactivateRegistryContract',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContract.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgDeactivateContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteContractCompat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/ExecuteContractCompat',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompat.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgExecuteContractCompatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/UpdateParams',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective.wasmx.v1.Msg/RegisterContract',
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContract.SerializeToString,
            injective_dot_wasmx_dot_v1_dot_tx__pb2.MsgRegisterContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
